@@ -1,4 +1,4 @@
-from models.reports.table_reports.approval_report import approval_report
+from models.reports.table_reports.approval_report import approval_report, approval_report_2
 from models.reports.table_reports.bin_report import bin_report
 from models.reports.table_reports.affid_report import affid_report
 from models.reports.table_reports.mtd_report import mtd_report
